==> RTCA_1.0.0.zip: RTCA/doc/aboutRTCA.R <==
###################################################
### chunk number 1: loadLib
###################################################
library(RTCA)


###################################################
### chunk number 2: dataImport
###################################################
ofile <-  system.file("extdata/testOutput.csv", package="RTCA")
x <- parseRTCA(ofile)


###################################################
### chunk number 3: dataImportFile eval=FALSE
###################################################
## ofile <- file.path("/directory/of/the/file/myFile.txt")


###################################################
### chunk number 4: printRTCA
###################################################
x


###################################################
### chunk number 5: annotate
###################################################
pfile <- system.file("extdata/testOutputPhenoData.csv", package="RTCA")
pData <- read.csv(pfile, sep="\t", row.names="Well")
metaData <- data.frame(labelDescription=c(
                         "Rack number",
                         "siRNA catalogue number",
                         "siRNA gene symbol",
                         "siRNA EntrezGene ID",
                         "siRNA targeting accession"
                         ))
phData <- new("AnnotatedDataFrame", data=pData, varMetadata=metaData)


###################################################
### chunk number 6: annotateAssign
###################################################
phenoData(x) <- phData


###################################################
### chunk number 7: annotatedx
###################################################
head(pData(x))


###################################################
### chunk number 8: alternativeAnnotate eval=FALSE
###################################################
## x <- parseRTCA(ofile, phenoData=phData)


###################################################
### chunk number 9: plotRTCA
###################################################
  plot(x[,1:4], type="l", col="black", lty=1:4, xlab="time point", ylab="Cell Index")


###################################################
### chunk number 10: addTimeLine
###################################################
x <- addAction(x, 22, "trasfection")
x <- addAction(x, 30, "medium change")


###################################################
### chunk number 11: extractTimeLine
###################################################
timeline(x)


###################################################
### chunk number 12: timeLineExamples
###################################################
tl <- timeline(x)
show(tl)
tlAdd <- addAction(tl, 35, "normalization"); tlAdd
getAction(tl, 22)
tlComp <- updateAction(tl, 22, "compound transfection")
tlComp
tlRm <- rmAction(tlAdd,35 ); tlRm


###################################################
### chunk number 13: ratioTransform
###################################################
xRatio <- ratioTransform(x, 35)
plot(xRatio[,1:4], lty=1:4, type="l", col="black",xlab="time point", ylab="Normalized Cell Index")
abline(v=35, col="red", lwd=2)


###################################################
### chunk number 14: plateView
###################################################
plateView(x, col="orange")


###################################################
### chunk number 15: sessionInfo
###################################################
toLatex(sessionInfo())

==> RTCA_1.2.0.zip: RTCA/doc/aboutRTCA.R <==
###################################################
### chunk number 1: loadLib
###################################################
#line 74 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp5VDrpx/R.INSTALL72ae2c3e/RTCA/inst/doc/aboutRTCA.Rnw"
library(RTCA)


###################################################
### chunk number 2: dataImport
###################################################
#line 79 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp5VDrpx/R.INSTALL72ae2c3e/RTCA/inst/doc/aboutRTCA.Rnw"
ofile <-  system.file("extdata/testOutput.csv", package="RTCA")
x <- parseRTCA(ofile)


###################################################
### chunk number 3: dataImportFile eval=FALSE
###################################################
## #line 85 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp5VDrpx/R.INSTALL72ae2c3e/RTCA/inst/doc/aboutRTCA.Rnw"
## ofile <- file.path("/directory/of/the/file/myFile.txt")


###################################################
### chunk number 4: printRTCA
###################################################
#line 90 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp5VDrpx/R.INSTALL72ae2c3e/RTCA/inst/doc/aboutRTCA.Rnw"
x


###################################################
### chunk number 5: annotate
###################################################
#line 103 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp5VDrpx/R.INSTALL72ae2c3e/RTCA/inst/doc/aboutRTCA.Rnw"
pfile <- system.file("extdata/testOutputPhenoData.csv", package="RTCA")
pData <- read.csv(pfile, sep="\t", row.names="Well")
metaData <- data.frame(labelDescription=c(
                         "Rack number",
                         "siRNA catalogue number",
                         "siRNA gene symbol",
                         "siRNA EntrezGene ID",
                         "siRNA targeting accession"
                         ))
phData <- new("AnnotatedDataFrame", data=pData, varMetadata=metaData)


###################################################
### chunk number 6: annotateAssign
###################################################
#line 117 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp5VDrpx/R.INSTALL72ae2c3e/RTCA/inst/doc/aboutRTCA.Rnw"
phenoData(x) <- phData


###################################################
### chunk number 7: annotatedx
###################################################
#line 121 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp5VDrpx/R.INSTALL72ae2c3e/RTCA/inst/doc/aboutRTCA.Rnw"
head(pData(x))


###################################################
### chunk number 8: alternativeAnnotate eval=FALSE
###################################################
## #line 126 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp5VDrpx/R.INSTALL72ae2c3e/RTCA/inst/doc/aboutRTCA.Rnw"
## x <- parseRTCA(ofile, phenoData=phData)


###################################################
### chunk number 9: plotRTCA
###################################################
#line 136 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp5VDrpx/R.INSTALL72ae2c3e/RTCA/inst/doc/aboutRTCA.Rnw"
  plot(x[,1:4], type="l", col="black", lty=1:4, xlab="time point", ylab="Cell Index")


###################################################
### chunk number 10: addTimeLine
###################################################
#line 151 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp5VDrpx/R.INSTALL72ae2c3e/RTCA/inst/doc/aboutRTCA.Rnw"
x <- addAction(x, 22, "trasfection")
x <- addAction(x, 30, "medium change")


###################################################
### chunk number 11: extractTimeLine
###################################################
#line 157 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp5VDrpx/R.INSTALL72ae2c3e/RTCA/inst/doc/aboutRTCA.Rnw"
timeline(x)


###################################################
### chunk number 12: timeLineExamples
###################################################
#line 162 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp5VDrpx/R.INSTALL72ae2c3e/RTCA/inst/doc/aboutRTCA.Rnw"
tl <- timeline(x)
show(tl)
tlAdd <- addAction(tl, 35, "normalization"); tlAdd
getAction(tl, 22)
tlComp <- updateAction(tl, 22, "compound transfection")
tlComp
tlRm <- rmAction(tlAdd,35 ); tlRm


###################################################
### chunk number 13: ratioTransform
###################################################
#line 179 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp5VDrpx/R.INSTALL72ae2c3e/RTCA/inst/doc/aboutRTCA.Rnw"
xRatio <- ratioTransform(x, 35)
plot(xRatio[,1:4], lty=1:4, type="l", col="black",xlab="time point", ylab="Normalized Cell Index")
abline(v=35, col="red", lwd=2)


###################################################
### chunk number 14: plateView
###################################################
#line 200 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp5VDrpx/R.INSTALL72ae2c3e/RTCA/inst/doc/aboutRTCA.Rnw"
plateView(x, col="orange")


###################################################
### chunk number 15: sessionInfo
###################################################
#line 214 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp5VDrpx/R.INSTALL72ae2c3e/RTCA/inst/doc/aboutRTCA.Rnw"
toLatex(sessionInfo())
